==> impresscms_1.1.3_final.tar.gz: htdocs/class/xml/xmltaghandler.php <==
<?php
// $Id: xmltaghandler.php 2 2005-11-02 18:23:29Z skalpa $
/*******************************************************************************
    Location: <b>xml/XmlTagHandler</b>

    XmlTagHandler

    Copyright &copy; 2001 eXtremePHP.  All rights reserved.

    @author Ken Egervari, Remi Michalski
*******************************************************************************/

class XmlTagHandler
{

    /****************************************************************************

    ****************************************************************************/
    function XmlTagHandler()
    {
    }

    /****************************************************************************

    ****************************************************************************/
    function getName()
    {
        return '';
    }

    /****************************************************************************

    ****************************************************************************/
    function handleBeginElement(&$parser, &$attributes)
    {

    }

    /****************************************************************************

    ****************************************************************************/
    function handleEndElement(&$parser)
    {

    }

    /****************************************************************************

    ****************************************************************************/
    function handleCharacterData(&$parser,  &$data)
    {

    }
}

?>

==> impresscms_1.2.6_final.tar.gz: htdocs/class/xml/xmltaghandler.php <==
<?php
// $Id$


/**
* XML Parser Tag Handler
*
*
/*******************************************************************************
*   Location: <b>xml/XmlTagHandler</b>
*
*   XmlTagHandler

*   @Copyright &copy; 2001 eXtremePHP.  All rights reserved.

*   @author Ken Egervari, Remi Michalski
*******************************************************************************
*
* @copyright	http://www.xoops.org/ The XOOPS Project
* @copyright	XOOPS_copyrights.txt
* @copyright	http://www.impresscms.org/ The ImpressCMS Project
* @license	LICENSE.txt
* @package	Administration
* @since	XOOPS
* @author	http://www.xoops.org The XOOPS Project
* @author	modified by UnderDog <underdog@impresscms.org>
* @version	$Id$
*/


class XmlTagHandler
{

    /****************************************************************************

    ****************************************************************************/
    function XmlTagHandler()
    {
    }

    /****************************************************************************

    ****************************************************************************/
    function getName()
    {
        return '';
    }

    /****************************************************************************

    ****************************************************************************/
    function handleBeginElement(&$parser, &$attributes)
    {

    }

    /****************************************************************************

    ****************************************************************************/
    function handleEndElement(&$parser)
    {

    }

    /****************************************************************************

    ****************************************************************************/
    function handleCharacterData(&$parser,  &$data)
    {

    }
}

?>
